<?php

/*  class WPSCMin
 *
 *  Singleton class add-on to WP Super Cache to interface with HTML Minify
 *  Author: Joel Hardi
 *  Author URI: http://lyncd.com
 *  Version 0.1
 *
 *  WP Super Cache, by Donncha O Caoimh, is a static caching plugin for WordPress
 *    For more information, see: http://ocaoimh.ie/wp-super-cache/
 *
 *  Minify is an HTML/CSS/JS whitespace compression library in PHP
 *    For more information, see: http://code.google.com/p/minify/
 *
 *  This class is a simple Singleton class that adds minification of static
 *  HTML and gzipped HTML files that WP Super Cache saves to the filesystem.
 *  It also adds a on/off configuration panel to WP Super Cache's WordPress
 *  settings page in the WordPress backend.
 *
 *  It requires associated patches to wp-cache.php and wp-cache-phase2.php
 *  and installation of Minify. See http://lyncd.com for install/usage instructions.
 *  Possibly Donncha will consider merging it into upstream WP Super Cache?
 *
 *  This version has been tested with WP Super Cace 0.8.4 and Minify 2.1.1
 */

class WPSCMin {
  private $enabled = FALSE; // Whether Minify is enabled
  private $changed = FALSE; // Whether value of $enabled has been changed

  public static $config_varname = 'cache_minify'; // Name of global config var set in wp-cache-config.php
  private static $instance;

  // Will run once only, since private and called only by getInstance()
  private function __construct() {
    // vars from wp-cache-config.php are initialized in global scope, so just 
    // get initial value of $enabled from there
    if (isset($GLOBALS[self::$config_varname]) and $GLOBALS[self::$config_varname])
      $this->enabled = TRUE;
  }

  public static function getInstance() {
    if (empty(self::$instance))
      self::$instance = new self();
    return self::$instance;
  }

  // Minifies string referenced by $html, if $this->enabled is TRUE
  public function minify(& $html) {
    if (!$this->enabled)
      return;

    // Include Minify components unless they have already been required
    if (!class_exists('Minify_HTML')) {
      require('min/lib/Minify/HTML.php');
      // Add min/lib to include_path for CSS.php to be able to find components
      ini_set('include_path', ini_get('include_path').':'.dirname(__FILE__).'/min/lib');
      require('min/lib/Minify/CSS.php');
      require('min/lib/JSMin.php');
    }

    $html = Minify_HTML::minify($html,
             array('cssMinifier' => array('Minify_CSS', 'minify'),
                   'jsMinifier' => array('JSMin', 'minify')));
  }

  public function updateOption($value, $config_file) {
    $enabled = (bool) $value;
    if ($enabled != $this->enabled) {
      $this->enabled = $enabled;
      $this->changed = TRUE;
      wp_cache_replace_line('^ *\$'.self::$config_varname, "\$".self::$config_varname." = " . var_export($enabled, TRUE) . ";", $config_file);
    }
  }

  public function printOptionsForm($action) {
    ?>
    <fieldset class="options"> 
    <h3>HTML Minify</h3>
    <form name="wp_manager" action="<?php echo $action; ?>" method="post">
      <label><input type="radio" name="<?php echo self::$config_varname; ?>" value="1" <?php if( $this->enabled ) { echo 'checked="checked" '; } ?>/> Enabled</label>
      <label><input type="radio" name="<?php echo self::$config_varname; ?>" value="0" <?php if( !$this->enabled ) { echo 'checked="checked" '; } ?>/> Disabled</label>
      <p>Enables or disables <a target="_blank" href="http://code.google.com/p/minify/">Minify</a> (stripping of unnecessary comments and whitespace) of cached HTML output. Disable this if you encounter any problems or need to read your source code.</p>
    <?php
    if ($this->changed) {
      echo "<p><strong>HTML Minify is now ";
      if ($this->enabled)
        echo "enabled";
      else
        echo "disabled";
      echo ".</strong></p>";
    }
    echo '<div class="submit"><input ' . SUBMITDISABLED . 'type="submit" value="Update Minify &raquo;" /></div>';
    wp_nonce_field('wp-cache');
    ?>

    </form>
    </fieldset><br />
    <?php
  }

}

?>
